@@ -38,8 +38,8 @@ public:
     int count() const;
     
     Q_INVOKABLE Transfer* addEnclosureDownload(const QString &url, bool usePlugin);
-    Q_INVOKABLE Transfer* addEnclosureDownload(const QString &url, const QString &command, const QString &category,
-            int priority, bool usePlugin);
+    Q_INVOKABLE Transfer* addEnclosureDownload(const QString &url, const QString &command, bool overrideGlobalCommand,
+            const QString &category, int priority, bool usePlugin);
     
     Q_INVOKABLE Transfer* get(int i) const;
     Q_INVOKABLE Transfer* get(const QString &id) const;
